[Qt] use libjpeg-turbo rather than Qt's built-in JPEG decoding

libjpeg-turbo is typically 2-4x faster than the built-in decoding.
This commit is contained in:
Konstantin Käfer
2016-01-20 16:42:16 +01:00
committed by Thiago Marcos P. Santos
parent 01b06c2301
commit e5c829b38c
3 changed files with 14 additions and 0 deletions

View File

@@ -3,6 +3,7 @@
BOOST_VERSION=1.59.0
GEOJSONVT_VERSION=4.1.2
GTEST_VERSION=1.7.0
LIBJPEG_TURBO_VERSION=1.4.2
NUNICODE_VERSION=1.6
PIXELMATCH_VERSION=0.9.0
RAPIDJSON_VERSION=1.0.2